'use strict';
var shell = require('shelljs');
var Download = require('download');
var Registry = require('npm-registry');

var npm = new Registry({});


module.exports = function(config) {
    var console = config.console;
    var directory = config.output;

    console.info('Fetching boilerplate metadata');

    return new Promise(function(resolve, reject) {
        npm.packages.get(config.boilerplate, function(err, data) {
            if(err) {
                return reject(err);
            }
            var meta = data.length && data[0];

            if(!meta) {
                return reject(new Error('Missing boilerplate metadata'));
            }

            var tarball = meta.latest.dist.tarball;

            var download = new Download({
                extract: true,
                strip: 1,
                mode: '755'
            }).get(tarball).dest(directory);

            console.info('Downloading boilerplate');

            download.run(function(err) {
                if(err) {
                    return reject(err);
                }

                console.info('Downloaded boilerplate');
                console.info('Installing dependencies');

                shell.cd(directory);
                shell.exec('npm install');

                console.info('Go to `' + directory +
                    '` and hit `antwar --develop` to get started');

                resolve();
            });
        });
    });
};
